==> ifrit_3.4.2.orig.tar.gz: ifrit-3.4.2/shells/generic/iggdialogdataexplorer.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2012 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef IGGDIALOGDATAEXPLORER_H
#define IGGDIALOGDATAEXPLORER_H


#include "iggdialog.h"
#include "idatastretch.h"


class iggFrameFlip;
class iggKeywordDataTypeProvider;


class iggDialogDataExplorer : public iggDialog, public iDataStretchUser
{

public:

	iggDialogDataExplorer(iggMainWindow *parent);
	virtual ~iggDialogDataExplorer();

	void ShowFractionInfo(bool s);

	inline iggKeywordDataTypeProvider* GetProvider() const { return mProvider; }

protected:

	virtual void CompleteConstructionBody();

	iggKeywordDataTypeProvider *mProvider;
	iggFrameFlip *mFlashFrame;
};

#endif  //  IGGDIALOGDATAEXPLORER_H

==> ifrit_4.1.2.orig.tar.gz: ifrit-4.1.2/shells/generic/iggdialogdataexplorer.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2012 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef IGGDIALOGDATAEXPLORER_H
#define IGGDIALOGDATAEXPLORER_H


#include "iggdialog.h"


class iDataType;

class iggFrameFlip;
class iggDataTypeHandle;


class iggDialogDataExplorer : public iggDialog
{

public:

	iggDialogDataExplorer(iggMainWindow *parent);
	virtual ~iggDialogDataExplorer();

	void ShowFractionInfo(bool s);

	const iDataType& GetActiveDataType() const;

protected:

	virtual void CompleteConstructionBody();

	iggFrameFlip *mFlashFrame;
	iggDataTypeHandle *mHandle;
};

#endif  //  IGGDIALOGDATAEXPLORER_H
